#!/usr/bin/perl
## expression.pl

use strict;
use warnings;

## get the filename from the argument
my $filename = shift;

## open the file
open IN, "<", $filename or die "Cannot open $filename: $!\n";

## create our hashes
my %tissues;
my %expressions;
my %sequences;

## read each line
while (my $line = <IN>) {

  ## remove the newline
  chomp $line;

  ## split our line to get the columns
  my @columns = split /\t/, $line;

  ## get the gene id
  my $gene_id = $columns[0];

  ## get the tissue
  my $tissue = $columns[1];

  ## get the expression
  my $expression = $columns[2];

  ## get the sequence
  my $sequence = $columns[3];

  ## populate %tissues
  $tissues{$gene_id} = $tissue;

  ## populate %expressions
  $expressions{$gene_id} = $expression;

  ## populate %sequences
  $sequences{$gene_id} = $sequence;
}

## array to hold gene ids with expression in liver
my @gene_ids_in_liver;

## go through each element in the %tissues hash
foreach my $gene_id (keys %tissues) {

  ## get the tissue
  my $tissue = $tissues{$gene_id};

  ## check to see if the tissue is liver
  if ($tissue eq "liver") {

    ## add to our array the gene id
    push @gene_ids_in_liver, $gene_id;

  }

}

## print expression data
foreach my $gene_id (@gene_ids_in_liver) {

  ## get the expression
  my $expression = $expressions{$gene_id};

  ## print
  print "$gene_id - $expression\n";

}

## close the file
close IN;
